| Title: | H.C. Andersens Fairy Tales |
|---|---|
| Description: | Texts for H.C. Andersens fairy tales, ready for text analysis. Fairy tales in German, Danish, English, Spanish and French. |
| Authors: | Emil Hvitfeldt [aut, cre] |
| Maintainer: | Emil Hvitfeldt <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-14 08:13:32 UTC |
| Source: | https://github.com/emilhvitfeldt/hcandersenr |
Eventyrkode (fairy tale code), stipulated by Svend Juel Møller in order to identify the fairy tales by H.C. Andersen
EKEK
A data frame with nine variables:
EKNumerical value for identification of fairy tales
dateDate of publication
approximateIs the date an approximation
org_languageOriginal language of the fairy tale
name_daName of the fairy tale in Danish
name_deName of the fairy tale in German
name_enName of the fairy tale in English
name_esName of the fairy tale in Spanish
name_frName of the fairy tale in French
A tidy data frame of all of H.C. Andersens fairy tales in this
pacakage with three columns: text, which contains the text of the
fairy tales divided into elements of up to about 80 characters each,
book, which contains the titles of the fairy tales in english, and
language which is the language of the text.
hca_fairytales()hca_fairytales()
A data frame with three variables: text,
book and language.
tales <- hca_fairytales() # See first few rows head(tales)tales <- hca_fairytales() # See first few rows head(tales)
A dataset containing 139 out of 157 of H.C. andersens fairy tales translated in Danish. The UTF-8 plain text was sourced from http://www.andersenstories.com/ and is divided into elements of up to about 80 characters each.
hcandersen_dahcandersen_da
A data frame with 20439 rows and 2 variables: text and
book.
A dataset containing 156 out of 157 of H.C. andersens fairy tales translated to German. The UTF-8 plain text was sourced from http://www.andersenstories.com/ and is divided into elements of up to about 80 characters each.
hcandersen_dehcandersen_de
A data frame with 28255 rows and 2 variables: text and
book.
A dataset containing 157 out of 157 of H.C. andersens fairy tales translated to English. The UTF-8 plain text was sourced from http://www.andersenstories.com/ and is divided into elements of up to about 80 characters each.
hcandersen_enhcandersen_en
A data frame with 27859 rows and 2 variables: text and
book.
A dataset containing 157 out of 157 of H.C. andersens fairy tales translated to Spanish. The UTF-8 plain text was sourced from http://www.andersenstories.com/ and is divided into elements of up to about 80 characters each.
hcandersen_eshcandersen_es
A data frame with 27510 rows and 2 variables: text and
book.
A dataset containing 61 out of 157 of H.C. andersens fairy tales translated to French The UTF-8 plain text was sourced from http://www.andersenstories.com/ and is divided into elements of up to about 80 characters each.
hcandersen_frhcandersen_fr
A data frame with 11184 rows and 2 variables: text and
book.
This package contains the (mostly) complete text of 157 fairy tales of H.C. Andersen, in a number of different languages. formatted to be convenient for text analysis.